#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_VALMAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_VALMAX_HPP_INCLUDED

#include <boost/simd/constant/include/constants/valmax.hpp>

#endif
